cmake_modules/FindFFMPEG.cmake
changeset 7540 cc6c656f70b5
parent 7538 2d6e69b392cb
child 7617 0ac281e1b58b
--- a/cmake_modules/FindFFMPEG.cmake	Fri Aug 10 17:35:48 2012 +0400
+++ b/cmake_modules/FindFFMPEG.cmake	Sat Aug 11 21:25:57 2012 +0400
@@ -1,7 +1,7 @@
 # - Try to find ffmpeg libraries (libavcodec, libavformat and libavutil)
 # Once done this will define
 #
 #  FFMPEG_FOUND - system has ffmpeg
 #  FFMPEG_INCLUDE_DIR - the ffmpeg include directory
 #  FFMPEG_LIBRARIES - Link these to use ffmpeg
 #  FFMPEG_LIBAVCODEC
@@ -67,11 +67,11 @@
 
   if (FFMPEG_FOUND)
     if (NOT FFMPEG_FIND_QUIETLY)
-      message(STATUS "Found FFMPEG: ${FFMPEG_LIBRARIES} ${FFMPEG_INCLUDE_DIR}")
+      message(STATUS "Found FFMPEG or Libav: ${FFMPEG_LIBRARIES}, ${FFMPEG_INCLUDE_DIR}")
     endif (NOT FFMPEG_FIND_QUIETLY)
   else (FFMPEG_FOUND)
     if (FFMPEG_FIND_REQUIRED)
-      message(FATAL_ERROR "Could not find FFMPEG libavcodec or libavformat or libavutil")
+      message(FATAL_ERROR "Could not find libavcodec or libavformat or libavutil")
     endif (FFMPEG_FIND_REQUIRED)
   endif (FFMPEG_FOUND)
@@ -1,7 +1,7 @@
 # Once done this will define
 #
-#  FFMPEG_FOUND - system has ffmpeg
+#  FFMPEG_FOUND - system has ffmpeg or libav
 #  FFMPEG_INCLUDE_DIR - the ffmpeg include directory
 #  FFMPEG_LIBRARIES - Link these to use ffmpeg